.. _cookies:

=================
Работа с кукисами
=================

Настройка кукисов
=================

Для того, чтобы отправить в запросе кукисы, используйте опцию :ref:`option_cookies`. Для того, чтобы кукисы, полученные в ответе сервера, автоматически подставлялись в следующие запросы, используйте опцию :ref:`option_reuse_cookies`. По-умолчанию, она включена.  

Если включены обе опции :ref:`option_cookies` и :ref:`option_reuse_cookies`, то запомненные кукисы будут объединяться с теми, что указаны в :ref:`option_cookies`.

Работа с файлом кукисов
=======================

Вы можете указать путь к файлу в опции :ref:`option_cookiefile`. Перед каждым запросом Grab будет считывать кукисы из этого файла и объединять с теми, что он уже помнит. После каждого запроса, Grab будет сохранять все кукисы в указанный файл. Эта опция полезна, если вам нужно сохранить сессию авторизованного пользователя между различными запусками программы.  Формат данных в файле: JSON-сериализованный словарь.

Для того, чтобы выгрузить кукисы Grab-объекта в файл, используйте метод `dump_cookies`. Для загрузки кукисов из файла используйте `load_cookies`.

Если вам нужно очистить все запомненные кукисы, воспользуйтесь методом `clear_cookies`, конкретно, он обнулит опцию :ref:`option_cookies`. Однако помните, если вы задали опцию :ref:`option_cookiefile`, то для следующего запроса, кукисы повторно загрузятся из этого файла.
